Struct grenad::RevPrefixIter [−][src]
pub struct RevPrefixIter<R> { /* fields omitted */ }Expand description
An iterator that is able to yield all the entries with a key that starts with a given prefix in reverse order.
Implementations