Struct grenad::MergerBuilder [−][src]
pub struct MergerBuilder<R, MF> { /* fields omitted */ }Expand description
A struct that is used to configure a Merger with the sources to merge.
Implementations
Creates a MergerBuilder from a merge function, it can be
used to configure your Merger with the sources to merge.
Add a source to merge, this function can be chained.
Push a source to merge, this function can be used in a loop.